==> gnome-utils-2.8.1.tar.bz2: gnome-utils-2.8.1/gdictsrc/gdict-speller.h <==
#ifndef __GDICT_SPELLER_H_
#define __GDICT_SPELLER_H_

/* $Id: gdict-speller.h,v 1.5 2003/11/10 01:49:50 gman Exp $ */

/*
 *  Mike Hughes <mfh@psilord.com>
 *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
 *  Bradford Hovinen <hovinen@udel.edu>
 *
 *  This code released under the GNU GPL.
 *  Read the file COPYING for more information.
 *
 *  GDict main window
 *
 */

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include <gtk/gtk.h>
#include <gnome.h>

#include "dict.h"

#define GDICT_SPELLER(obj)         GTK_CHECK_CAST (obj, gdict_speller_get_type (), GDictSpeller)
#define GDICT_SPELLER_CLASS(klass) GTK_CHECK_CLASS_CAST (klass, gdict_speller_get_type (), GDictSpellerClass)
#define IS_GDICT_SPELLER(obj)      GTK_CHECK_TYPE (obj, gdict_speller_get_type ())

typedef struct _GDictSpeller        GDictSpeller;
typedef struct _GDictSpellerClass   GDictSpellerClass;

struct _GDictSpeller {
    GtkDialog      dialog;
    
    dict_context_t *context;
    dict_command_t *get_strat_cmd;
    dict_command_t *spell_cmd;
    gchar          *database;
    gchar          *strat;
    
    GtkWidget      *hbox;
    GtkEntry       *word_entry;    
    GtkOptionMenu  *strat_sel;
    GtkMenu        *strat_list;
    guint           strat_idx;
    GtkWidget	   *word_list;
    
    gchar          *current_word;
};

struct _GDictSpellerClass {
    GtkDialogClass  parent_class;
    
    void (*word_lookup_start) (GDictSpeller *);
    void (*word_lookup_done)  (GDictSpeller *);
    void (*word_not_found)    (GDictSpeller *);
    void (*socket_error)      (GDictSpeller *, gchar *);
};

GType      gdict_speller_get_type    (void);

GtkWidget *gdict_speller_new         ();
void       gdict_speller_destroy     (GDictSpeller *speller);

gint       gdict_speller_lookup      (GDictSpeller *speller, gchar *text);
void       gdict_speller_clear       (GDictSpeller *speller);
void       gdict_speller_reset       (GDictSpeller *speller,
                                      dict_context_t *context);

gchar     *gdict_speller_get_word    (GDictSpeller *speller);

void       gdict_speller_reset_strat (GDictSpeller *speller);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GDICT_SPELLER_H_ */

==> gnome-utils-2.9.2.tar.bz2: gnome-utils-2.9.2/gdictsrc/gdict-speller.h <==
#ifndef __GDICT_SPELLER_H_
#define __GDICT_SPELLER_H_

/* $Id: gdict-speller.h,v 1.6 2004/11/04 00:36:37 pborelli Exp $ */

/*
 *  Mike Hughes <mfh@psilord.com>
 *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
 *  Bradford Hovinen <hovinen@udel.edu>
 *
 *  This code released under the GNU GPL.
 *  Read the file COPYING for more information.
 *
 *  GDict main window
 *
 */

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#include <gtk/gtk.h>

#include "dict.h"

#define GDICT_TYPE_SPELLER            (gdict_speller_get_type ())
#define GDICT_SPELLER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GDICT_TYPE_SPELLER, GDictSpeller))
#define GDICT_SPELLER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GDICT_TYPE_SPELLER, GDictSpellerClass))
#define GDICT_IS_SPELLER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GDICT_TYPE_SPELLER))
#define GDICT_IS_SPELLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDICT_TYPE_SPELLER))
#define GDICT_SPELLER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GDICT_TYPE_SPELLER, GDictSpellerClass))


typedef struct _GDictSpeller        GDictSpeller;
typedef struct _GDictSpellerClass   GDictSpellerClass;

struct _GDictSpeller {
    GtkDialog      dialog;
    
    dict_context_t *context;
    dict_command_t *get_strat_cmd;
    dict_command_t *spell_cmd;
    gchar          *database;
    gchar          *strat;
    
    GtkWidget      *hbox;
    GtkEntry       *word_entry;
    GtkWidget      *strat_label;
    GtkOptionMenu  *strat_sel;
    GtkMenu        *strat_list;
    guint           strat_idx;
    GtkWidget	   *word_list;
    
    gchar          *current_word;
};

struct _GDictSpellerClass {
    GtkDialogClass  parent_class;
    
    void (*word_lookup_start) (GDictSpeller *);
    void (*word_lookup_done)  (GDictSpeller *);
    void (*word_not_found)    (GDictSpeller *);
    void (*socket_error)      (GDictSpeller *, gchar *);
};

GType      gdict_speller_get_type    (void);

GtkWidget *gdict_speller_new         ();
void       gdict_speller_destroy     (GDictSpeller *speller);

gint       gdict_speller_lookup      (GDictSpeller *speller, gchar *text);
void       gdict_speller_clear       (GDictSpeller *speller);
void       gdict_speller_reset       (GDictSpeller *speller,
                                      dict_context_t *context);

gchar     *gdict_speller_get_word    (GDictSpeller *speller);

void       gdict_speller_reset_strat (GDictSpeller *speller);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GDICT_SPELLER_H_ */
